Overview
========

MySmile is the lightweight open-source CMS based on Django. It helps to create websites with configurable design at minimum cost. MySmile is the best choice for:

* Small websites aiming at a static content with limited dynamics. For example such as: "Startup business", "Personal site", "Conference".
* Some prototypes/ideas that now look insignificant but have enormous potential to grow. Because MySmile uses Django framework it breaks all barriers for implementation of your new features.
* Freshmen Python developers for studying and experimenting.

Innovations of MySmile features:

* Use of newspaper text organizing technology such as: columns, incuts.
* REST API helps construct mobile and desktop application
* Moreover REST API client is available, for now it is php client with examples and unitTests
* Design can be modified by admin panel without any additional program coding.
* There are more then 27 unique designers combination! How we get them? Let's look into calculation. Every page consists of the 3 parts: central-column, right-column, bottom-column. Right-column can have 3 columns. And right-column has also 3 components: photo, youtube, text. Additionally every element can or can't be present.
* Additional menu is created dynamically from pages that are avaliable on a page as a link. It works like mix of "cloud of links" and "bread crumbs". So when you open links they appear on the menu.

Source code is available on `GitHub <https://github.com/MySmile/MySmile.git/>`_. 

Get the latest version with the command: ``$ git clone --branch=master git@github.com:MySmile/mysmile.git``

See unstable development version: ``$ git clone --branch=dev git@github.com:MySmile/mysmile.git``

Please read this documentation or try `<http://demo.mysmile.com.ua/>`_ for more information.
